@@ -35,7 +35,7 @@
 #' @author \href{https://declaredesign.org/}{DeclareDesign Team}
 #' @concept qualitative 
 #' @concept process tracing
-#' @importFrom DeclareDesign declare_diagnosands declare_inquiry declare_estimator declare_population declare_sampling declare_step diagnose_design draw_data draw_inquiries draw_estimates set_diagnosands
+#' @importFrom DeclareDesign declare_diagnosands declare_inquiry declare_estimator declare_population declare_sampling declare_step diagnose_design draw_data draw_estimands draw_estimates set_diagnosands
 #' @importFrom fabricatr fabricate fabricate
 #' @importFrom randomizr conduct_ra draw_rs 
 #' @importFrom stats rbinom
@@ -45,7 +45,7 @@
 #' @examples
 #' # Generate a process-tracing design using default arguments:
 #' pt_1 <- process_tracing_designer()
-#' draw_inquiries(pt_1)
+#' draw_estimands(pt_1)
 #' draw_estimates(pt_1)
 #' draw_data(pt_1)
 #' \dontrun{
@@ -118,8 +118,8 @@ process_tracing_designer <- function(
     )
     # D: Data Strategy 1
     select_case <- declare_sampling(
-      strata = paste(X, Y),
-      strata_n = c("X0Y0" = 0, "X0Y1" = 0, "X1Y0" = 0, "X1Y1" = 1))
+      S = strata_rs(strata = paste(X, Y),
+      strata_n = c("X0Y0" = 0, "X0Y1" = 0, "X1Y0" = 0, "X1Y1" = 1)))
     # I: Inquiry
     estimand <-
       declare_inquiry(did_X_cause_Y = causal_process == 'X_causes_Y')
